#ifndef EXTRA_COMMAND_H
#define EXTRA_COMMAND_H

#include "nodes/parsenodes.h"

struct _DestReceiver;

extern void ExecKillStmt(KillStmt *stmt);
extern void ExecShowSchemas(char *pattern, struct _DestReceiver *dest);
extern void ExecShowDatabases(char *pattern, struct _DestReceiver *dest);
extern void ExecShowTables(char *pattern, char *schema, struct _DestReceiver *dest);
extern void ExecShowCreateTable(ShowCreateTableStmt *stmt, struct _DestReceiver *dest);
extern void ExecShowProcessList(bool local, struct _DestReceiver *dest);
extern void ExecSendShardStmt(char *shard, char *query, struct _DestReceiver *dest);
extern void ExecSendShardStmtInternal(Oid shardid, const char *query, struct _DestReceiver *dest);

#endif
